==> embunit-src-1.0.tar.gz: embunit/embUnit/RepeatedTest.c <==
/*
 * COPYRIGHT AND PERMISSION NOTICE
 * 
 * Copyright (c) 2003 Embedded Unit Project
 * 
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining 
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal in the Software without restriction, including 
 * without limitation the rights to use, copy, modify, merge, publish, 
 * distribute, and/or sell copies of the Software, and to permit persons 
 * to whom the Software is furnished to do so, provided that the above 
 * copyright notice(s) and this permission notice appear in all copies 
 * of the Software and that both the above copyright notice(s) and this 
 * permission notice appear in supporting documentation.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT 
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY 
 * SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER 
 * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF 
 * CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * Except as contained in this notice, the name of a copyright holder 
 * shall not be used in advertising or otherwise to promote the sale, 
 * use or other dealings in this Software without prior written 
 * authorization of the copyright holder.
 *
 * $Id: RepeatedTest.c,v 1.2 2003/09/05 11:28:55 arms22 Exp $
 */
#include "RepeatedTest.h"

char* RepeatedTest_name(RepeatedTestRef self)
{
	return Test_name(self->test);
}

void RepeatedTest_run(RepeatedTestRef self,TestResultRef result)
{
	int i;
	TestRef test = self->test;
	for (i=0; i<self->timesRepeat; i++) {
		Test_run(test, result);
	}
}

int RepeatedTest_countTestCases(RepeatedTestRef self)
{
	return Test_countTestCases(self->test) * self->timesRepeat;
}

const TestImplement RepeatedTestImplement = {
	(TestTypeID)				RepeatedTestTypeID,
	(TestNameFunction)			RepeatedTest_name,
	(TestRunFunction)			RepeatedTest_run,
	(TestCountTestCasesFunction)RepeatedTest_countTestCases,
};

==> embunit-src-1.0.1.tar.gz: embunit/embUnit/RepeatedTest.c <==
/*
 * COPYRIGHT AND PERMISSION NOTICE
 * 
 * Copyright (c) 2003 Embedded Unit Project
 * 
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining 
 * a copy of this software and associated documentation files (the 
 * "Software"), to deal in the Software without restriction, including 
 * without limitation the rights to use, copy, modify, merge, publish, 
 * distribute, and/or sell copies of the Software, and to permit persons 
 * to whom the Software is furnished to do so, provided that the above 
 * copyright notice(s) and this permission notice appear in all copies 
 * of the Software and that both the above copyright notice(s) and this 
 * permission notice appear in supporting documentation.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT 
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY 
 * SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER 
 * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF 
 * CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * Except as contained in this notice, the name of a copyright holder 
 * shall not be used in advertising or otherwise to promote the sale, 
 * use or other dealings in this Software without prior written 
 * authorization of the copyright holder.
 *
 * $Id: RepeatedTest.c,v 1.5 2004/02/10 16:19:29 arms22 Exp $
 */
#include "Test.h"
#include "RepeatedTest.h"

char* RepeatedTest_name(RepeatedTest* self)
{
	return Test_name(self->test);
}

void RepeatedTest_run(RepeatedTest* self,TestResult* result)
{
	int i;
	Test* test = self->test;
	for (i=0; i<self->timesRepeat; i++) {
		Test_run(test, result);
	}
}

int RepeatedTest_countTestCases(RepeatedTest* self)
{
	return Test_countTestCases(self->test) * self->timesRepeat;
}

const TestImplement RepeatedTestImplement = {
	(TestNameFunction)			RepeatedTest_name,
	(TestRunFunction)			RepeatedTest_run,
	(TestCountTestCasesFunction)RepeatedTest_countTestCases,
};
